#
# spec file for package python-pyflakes
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without  test
Name:           python-pyflakes
Version:        2.1.1
Release:        150000.3.2.2
Summary:        Passive checker of Python programs
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/PyCQA/pyflakes
Source:         https://files.pythonhosted.org/packages/source/p/pyflakes/pyflakes-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# the pkg_resources module is required at runtime
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Pyflakes is program to analyze Python programs and detect various errors. It
works by parsing the source file, not importing it, so it is safe to use on
modules with side effects. It's also much faster.

%prep
%setup -q -n pyflakes-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/pyflakes/
%python_clone -a %{buildroot}%{_bindir}/pyflakes

%if %{with test}
%check
%python_exec setup.py test
%endif

%post
%python_install_alternative pyflakes

%postun
%python_uninstall_alternative pyflakes

%files %{python_files}
%license LICENSE
%doc NEWS.rst README.rst AUTHORS
%python_alternative %{_bindir}/pyflakes
%{python_sitelib}/pyflakes/
%{python_sitelib}/pyflakes-%{version}-py*.egg-info

%changelog
* Sat Mar  2 2019 arun@gmx.de
- update to version 2.1.1:
  * Fix reported line number for type comment errors
  * Fix typing.overload check to only check imported names
* Sat Jan 26 2019 arun@gmx.de
- specfile:
  * update copyright year
  * renamed NEWS.txt -> NEWS.rst
- update to version 2.1.0:
  * Allow intentional assignment to variables named _
  * Recognize __module__ as a valid name in class scope
  * pyflakes.checker.Checker supports checking of partial ast trees
  * Detect assign-before-use for local variables which shadow builtin
    names
  * Detect invalid print syntax using >> operator
  * Treat async for the same as a for loop for introducing variables
  * Add detection for list concatenation in __all__
  * Exempt @typing.overload from duplicate function declaration
  * Importing a submodule of an as-aliased import-import is marked as
    used
  * Report undefined names from __all__ as possibly coming from a *
    import
  * Add support for changes in Python 3.8-dev
  * Add support for PEP 563 (from __future__ import annotations)
  * Include Python version and platform information in pyflakes
  - -version
  * Recognize __annotations__ as a valid magic global in Python 3.6+
  * Mark names used in PEP 484 # type: ... comments as used
  * Add check for use of is operator with str, bytes, and int literals
* Mon Jul 30 2018 t.gruner@katodev.de
- update to version 2.0.0:
  * Drop support for EOL Python <2.7 and 3.2-3.3
  * Check for unused exception binding in `except:` block
  * Handle string literal type annotations
  * Ignore redefinitions of `_`, unless originally defined by import
  * Support `__class__` without `self` in Python 3
  * Issue an error for `raise NotImplemented(...)`
* Wed Jan 17 2018 toddrme2178@gmail.com
- Implement tests
- Fix source and URL
* Sun Sep 24 2017 arun@gmx.de
- update to version 1.6.0:
  * Process function scope variable annotations for used names
  * Find Python files without extensions by their shebang
* Wed Mar 29 2017 jmatejek@suse.com
- uninstall alternatives in %%postun
* Mon Feb 20 2017 jmatejek@suse.com
- update for singlespec
* Wed Feb 15 2017 kkaempf@suse.com
- update to version 1.5.0:
  * Enable support for PEP 526 annotated assignments
- update to version 1.4.0:
  * Change formatting of ImportStarMessage to be consistent with
    other errors
  * Support PEP 498 "f-strings"
- update to version 1.3.0:
  * Fix PyPy2 Windows IntegrationTests
  * Check for duplicate dictionary keys
  * Fix TestMain tests on Windows
  * Fix "continue" and "break" checks ignoring py3.5's "async for" loop
- update to version 1.2.3:
  * Fix TypeError when processing relative imports
- update to version 1.2.2:
  * Avoid traceback when exception is del-ed in except
- update to version 1.2.1:
  * Fix false RedefinedWhileUnesed for submodule imports
- update to version 1.2.0:
  * Warn against reusing exception names after the except: block on
    Python 3
  * Improve the error messages for imports
- update to version 1.1.0:
  * main() can now accept arguments
  * the matrix-multiplication operator (@) is now supported
  * imports from __future__ are checked for validity
  * fixes to doctest scope testing
  * asserts against a tuple (which are always true) now emits a warning
  * "import *" not at the module level on python3 emits a warning
  * many kinds of SyntaxErrors not previously caught now are
  * PEP 498 f-strings are checked
  * and a few more sundry bugfixes
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Wed Jan 13 2016 toddrme2178@gmail.com
- update to version 1.0.0:
  * Python 3.5 support. async/await statements in particular.
  * test_api.py works on Windows now
  * Eliminated a false UnusedImport warning when the name has been
    declared "global"
- Implement update-alternatives.
* Tue Nov 10 2015 opensuse@cboltz.de
- add dependency on python-setuptools (the pkg_resources module is needed
  at runtime)
* Mon Jun 22 2015 tbechtold@suse.com
- update to 0.9.2:
  - Fix a traceback when a global is defined in one scope, and used in another.
  - Update NEWS.txt to include 0.9.0, which had been forgotten.
  - Exit gracefully, not with a traceback, on SIGINT and SIGPIPE.
  - Fix incorrect report of undefined name when using lambda expressions in
    generator expressions.
  - Don't crash on DOS line endings on Windows and Python 2.6.
  - Don't report an undefined name if the 'del' which caused a name to become
    undefined is only conditionally executed.
  - Properly handle differences in list comprehension scope in Python 3.
  - Improve handling of edge cases around 'global' defined variables.
  - Report an error for 'return' outside a function.
* Fri Apr 11 2014 toddrme2178@gmail.com
- Update to 0.8.1:
  - Detect the declared encoding in Python 3.
  - Do not report redefinition of import in a local scope, if the
    global name is used elsewhere in the module.
  - Catch undefined variable in loop generator when it is also used as
    loop variable.
  - Report undefined name for `(a, b) = (1, 2)` but not for the general
    unpacking `(a, b) = func()`.
  - Correctly detect when an imported module is used in default arguments
    of a method, when the method and the module use the same name.
  - Distribute a universal wheel file.
- Update to 0.8.0:
  - Adapt for the AST in Python 3.4.
  - Fix caret position on SyntaxError.
  - Fix crash on Python 2.x with some doctest SyntaxError.
  - Add tox.ini.
  - The `PYFLAKES_NODOCTEST` environment variable has been replaced with the
    `PYFLAKES_DOCTEST` environment variable (with the opposite meaning).
    Doctest checking is now disabled by default; set the environment variable
    to enable it.
  - Correctly parse incremental `__all__ += [...]`.
  - Catch return with arguments inside a generator (Python <= 3.2).
  - Do not complain about `_` in doctests.
  - Drop deprecated methods `pushFunctionScope` and `pushClassScope`.
* Tue Nov 19 2013 dmueller@suse.com
- install LICENSE (and other usual boilerplate)
* Wed Jul  3 2013 dmueller@suse.com
- update to 0.7.3:
  - Do not report undefined name for generator expression and dict or
    set comprehension at class level.
  - Deprecate `Checker.pushFunctionScope` and `Checker.pushClassScope`:
    use `Checker.pushScope` instead.
  - Remove dependency on Unittest2 for the tests.
* Mon May 13 2013 dmueller@suse.com
- update to 0.7.2:
  - Fix computation of `DoctestSyntaxError.lineno` and `col`.
  - Add boolean attribute `Checker.withDoctest` to ignore doctests.
  - If environment variable `PYFLAKES_NODOCTEST` is set, skip doctests.
  - Environment variable `PYFLAKES_BUILTINS` accepts a comma-separated
    list of additional built-in names.
  - File `bin/pyflakes` was missing in tarball generated with distribute.
  - Fix reporting errors in non-ASCII filenames (Python 2.x)
* Sun Apr 21 2013 dmueller@suse.com
- update to 0.7:
  - Add --version and --help options.
  - Support `python -m pyflakes` (Python 2.7 and Python 3.x).
  - Add attribute `Message.col` to report column offset.
  - Do not report redefinition of variable for a variable used in a list
    comprehension in a conditional.
  - Do not report redefinition of variable for generator expressions and
    set or dict comprehensions.
  - Do not report undefined name when the code is protected with a
    `NameError` exception handler.
  - Do not report redefinition of variable when unassigning a module imported
    for its side-effect.
  - Support special locals like `__tracebackhide__` for py.test.
  - Support checking doctests.
  - Fix issue with Turkish locale where `'i'.upper() == 'i'` in Python 2.
  - Fix detection of variables in augmented assignments.
  - Support Python 3 up to 3.3, based on the pyflakes3k project.
  - Preserve compatibility with Python 2.5 and all recent versions of Python.
  - Support custom reporters in addition to the default Reporter.
  - Allow function redefinition for modern property construction via
    property.setter/deleter.
  - Fix spurious redefinition warnings in conditionals.
  - Do not report undefined name in __all__ if import * is used.
  - Add WindowsError as a known built-in name on all platforms.
  - Support specifying additional built-ins in the `Checker` constructor.
  - Don't issue Unused Variable warning when using locals() in current scope.
  - Handle problems with the encoding of source files.
  - Remove dependency on Twisted for the tests.
  - Support `python setup.py test` and `python setup.py develop`.
  - Create script using setuptools `entry_points` to support all platforms,
* Fri Apr 27 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4 x86_64
* Thu Apr 26 2012 toddrme2178@gmail.com
- Add python 3 package
* Mon Feb 13 2012 alexandre@exatati.com.br
- Renegerate spec file with py2pack;
- Add missing changes for 0.5.0.
* Sun Feb 12 2012 werner.ho@gmx.de
- New version 0.5.0:
  - Convert pyflakes to use newer _ast infrastructure rather than compiler.
  - Support for new syntax in 2.7 (including set literals, set comprehensions,
    and dictionary comprehensions).
  - Make sure class names don't get bound until after class definition.
* Mon Dec 28 2009 alexandre@exatati.com.br
- Initial package (0.4.0) for openSUSE.
